@@ -1,3 +1,5 @@
+/* $Id: cpu_openbsd.c,v 1.1.1.1 2002/10/14 09:31:17 sch Exp $ */
+
 /*
  * cpu_openbsd - module to get cpu usage, for OpenBSD
  *
@@ -20,14 +22,16 @@
 #include <sys/sysctl.h>
 #include <sys/dkstat.h>
 
-void cpu_init(void)
+void
+cpu_init(void)
 {
     /* You don't need initialization under OpenBSD */
     return;
 }
 
 /* Returns the current CPU usage in percent */
-int cpu_get_usage(struct cpu_options *opts)
+int
+cpu_get_usage(cpu_options *opts)
 {
     int total, used, result;
     static int pre_total, pre_used;
@@ -42,16 +46,18 @@ int cpu_get_usage(struct cpu_options *opts)
 
     /* calc usage */
     used = cpu_time[CP_USER] + cpu_time[CP_SYS];
-    if (!opts->ignore_nice)
+    if (!opts->ignore_nice) {
 	used += cpu_time[CP_NICE];
+    }
     total = used + cpu_time[CP_IDLE];
 
-    if (pre_total == 0)
+    if (pre_total == 0) {
 	result = 0;
-    else if ((total - pre_total) > 0)
+    } else if ((total - pre_total) > 0) {
 	result = 100 * (double)(used - pre_used) / (double)(total - pre_total);
-    else
+    } else {
 	result = 0;
+    }
 
     /* save used/total for next calculation */
     pre_used = used;
